@@ -1,4 +1,7 @@
 package Yahoo::Search;
+BEGIN {
+  $Yahoo::Search::VERSION = '1.11.1';
+}
 use strict;
 use Carp;
 use Yahoo::Search::Request;
@@ -7,18 +10,11 @@ use Yahoo::Search::Request;
 ## This is the interface to Yahoo!'s web search API.
 ## Written by Jeffrey Friedl <jfriedl@yahoo.com>
 ##
-## Copyright 2007 Yahoo! Inc.
-##
 ## Master source:
 ##
 ##   http://search.cpan.org/search?mode=module&n=1&query=Yahoo::Search
 ##
 
-our $VERSION = '1.10.13'; # Last num increases monotonically across all versions.
-                          # See the "Changes" file (comes with the CPAN package)
-                          # for version history.
-
-
 ##
 ## CLASS OVERVIEW
 ##
@@ -64,6 +60,7 @@ my %Config =
                 Language     => undef,
                 Country      => undef,
                 License      => undef,
+                Region       => undef,
                },
 
    QueryOptional => 1,
@@ -627,6 +624,7 @@ my %ValidateRoutine =
  PostalCode   => $allow_postal_code,
  Language     => $allow_language_code,
  Country      => $allow_country_code,
+ Region       => $allow_country_code,
 
  Mode      => sub { $allow_from_hash->(0, $Config{$_[0]}->{AllowedMode}, @_) },
  Sort      => sub { $allow_from_hash->(0, $Config{$_[0]}->{AllowedSort}, @_) },
@@ -777,6 +775,7 @@ my %ArgToParam =
  Mode         => 'type',
  PostalCode   => 'zip',
  Radius       => 'radius',
+ Region       => 'region',
  Sort         => 'sort',
  Start        => 'start',
  State        => 'state',
@@ -955,10 +954,10 @@ sub Request
 
     ##
     ## Ensure that the Count, if given, is not over max
-    ##
-    if (defined $Param{count} and $Param{count} > $Config{$SearchSpace}->{MaxCount}) {
-        return _carp_on_error("maximum allowed Count for a $SearchSpace search is $Config{$SearchSpace}->{MaxCount}");
-    }
+    ## No longer enforced here. MaxCount is only advisory now.
+    #if (defined $Param{count} and $Param{count} > $Config{$SearchSpace}->{MaxCount}) {
+    #    return _carp_on_error("maximum allowed Count for a $SearchSpace search is $Config{$SearchSpace}->{MaxCount}");
+    #}
 
     ##
     ## If License is given, it an have multiple values (space, comma, or
@@ -1102,6 +1101,10 @@ __END__
 
 Yahoo::Search - Perl interface to the Yahoo! Search public API.
 
+=head1 VERSION
+
+version 1.11.1
+
 The following search spaces are supported:
 
 =over 3
@@ -1290,6 +1293,7 @@ showing which apply to queries of which search space:
   AllowAdult      [X]    [X]    [X]     .      .      .      .      .
   Type            [X]    [X]    [X]     .      .      .      .      .
   Language        [X]     .      .     [X]     .      .      .      .
+  Region          [X]     .      .      .      .      .      .      .
   Sort             .      .      .     [X]    [X]     .      .      .
   Color            .     [X]     .      .      .      .      .      .
       .
@@ -1312,7 +1316,7 @@ Here are details of each:
 
 =item AppId
 
-A 8-40 character string which identifies the application making use of the
+A character string which identifies the application making use of the
 Yahoo! Search API. (Think of it along the lines of an HTTP User-Agent
 string.)
 
@@ -1350,8 +1354,8 @@ returned.
 =item Count
 
 Indicates how many items should be returned. The default is 10. The maximum
-allowed depends on the search space being queried: B<20> for I<Local>
-searches, and B<50> for others which support the C<Count> argument.
+allowed depends on the search space being queried. The maximum isn't
+enforced by this module.
 
 Note that
 
@@ -1361,7 +1365,8 @@ and
 
   $SearchEngine->MaxCount($SearchSpace)
 
-return the maximum count allowed for the given C<$SearchSpace>.
+return the assumed maximum count allowed for the given C<$SearchSpace>.
+These counts may be out of date.
 
 =item Context
 
@@ -1435,6 +1440,44 @@ of this specific list. If you provide a C<Country> value which is not
 supported by Yahoo!'s web services, a "400 Bad Request" error is returned
 in C<@$>.
 
+=item Region
+
+Uses a different regional version of the Yahoo! web service. For
+example, setting C<Region> to "de" will show the results as returned
+from de.search.yahoo.com. Note that this does not restrict the results
+in the way C<Country> and C<Language> do, but will merely lead to a
+different weighting of the results. As of this writing, the Yahoo! web
+services support the following codes for C<Region>:
+
+ code   country
+ ----   ---------------
+  ar    Argentina
+  au    Australia
+  at    Austria
+  br    Brazil
+  ca    Canada
+  ct    Catalan
+  dk    Denmark
+  fi    Finland
+  fr    France
+  de    Germany
+  in    India
+  id    Indonesia
+  it    Italy
+  my    Malaysia
+  mx    Mexico
+  nl    Netherlands
+  no    Norway
+  ph    Phillipines
+  ru    Russian Federation
+  sg    Singapore
+  es    Spain
+  se    Sweden
+  ch    Switzerland
+  th    Thailand
+  uk    United Kingdom
+  us    United States (yahoo.com)
+
 =item License
 
 For C<Doc> searches, can be:
@@ -2027,7 +2070,8 @@ pair (which is required) is required to appear first.
 
 =item $num = Yahoo::Search->MaxCount($space)
 
-Returns the maximum allowed C<Count> query-argument for the given search space.
+Returns the assumed maximum allowed C<Count> query-argument for the given search space.
+The amount may be out of date.
 
 
 
@@ -2179,12 +2223,16 @@ Yahoo::Search uses LWP to communicate with Yahoo!'s servers; LWP uses
 environment variables such as C<http_proxy> and C<no_proxy>. See the
 perldoc for LWP for more.
 
-=head1 Copyright
-
-Copyright 2007 Yahoo! Inc.
-
 =head1 Author
 
 Jeffrey Friedl (jfriedl@yahoo.com)
 
-=cut
+Jeffrey placed the 1.10.13 code in the public domain (or, technically, the
+http://creativecommons.org/publicdomain/zero/1.0/ licence) on June 11th 2010.
+Tim Bunce (Tim.Bunce@pobox.com) currently maintains the code, though with very
+little spare much time. He's very happy for someone else to help out.
+
+Please use https://rt.cpan.org/Dist/Display.html?Queue=Yahoo-Search to
+submit bug reports.
+
+=cut
\ No newline at end of file
