@@ -7,7 +7,7 @@ use LWP::UserAgent;
 use HTTP::Request;
 use URI;
 
-our $VERSION = "20070320.002"; # just to make CPAN happy
+our $VERSION = "20100611.002"; # just to make CPAN happy
 
 
 my $have_XML_Simple; # undef means 'not yet tested'
@@ -27,6 +27,10 @@ sub _have_XML_Simple
 
 =head1 NAME
 
+
+=head1 VERSION
+
+version 1.11.1
 Yahoo::Search::Request -- Container object for a Yahoo! Search request.
 (This package is included in, and automatically loaded by, the Yahoo::Search package.)
 
@@ -302,7 +306,7 @@ sub Fetch
             ##
             if (not _have_XML_Simple())
             {
-                warn "Yahoo::Search::XML is having trouble with the XML returned from Yahoo; try installing XML::Simple and setting \$Yahoo::Search::UseXmlSimple to true, and filing a bug report with jfriedl\@yahoo.com.\n";
+                warn "Yahoo::Search::XML is having trouble with the XML returned from Yahoo ($orig_error); try installing XML::Simple and setting \$Yahoo::Search::UseXmlSimple to true, and filing a bug report.\n";
                 $@ = "Yahoo::Request: Error processing XML: $orig_error";
                 return ();
             }
@@ -310,7 +314,7 @@ sub Fetch
             $ResultHash = eval { XML::Simple::XMLin($xml) };
 
             if (not $ResultHash) {
-                $@ = "Yahoo::Request: Error processing XML (even tried XML::Simple): $orig_error";
+                $@ .= "Yahoo::Request: Error processing XML (even tried XML::Simple): $orig_error";
                 return ();
             }
             ##
@@ -318,7 +322,7 @@ sub Fetch
             ## so it must be a bug with the former... )_:
             ##
             $Yahoo::Search::UseXmlSimple = 1;
-            warn "Yahoo::Search::XML is having trouble with the XML returned from Yahoo, so reverting to XML::Simple; suggest setting \$Yahoo::Search::UseXmlSimple to true and filing a bug report with jfriedl\@yahoo.com.\n";
+            warn "Yahoo::Search::XML is having trouble with the XML returned from Yahoo ($orig_error), so reverting to XML::Simple; suggest setting \$Yahoo::Search::UseXmlSimple to true and filing a bug report.\n";
         }
     }
 
@@ -462,14 +466,10 @@ sub SpellResponse
 
 =back
 
-=head1 Copyright
-
-Copyright 2007 Yahoo! Inc.
-
 =head1 Author
 
 Jeffrey Friedl (jfriedl@yahoo.com)
 
 =cut
 
-1;
+1;
\ No newline at end of file
